@@ -60,7 +60,7 @@ class DisconnectButton(discord.ui.Button):
 
         await self.view.prepare()
         kwargs = await self.view.get_page(self.view.current_page)
-        await (await interaction.original_message()).edit(view=self.view, **kwargs)
+        await context.message.edit(view=self.view, **kwargs)
 
 
 class StopTrackButton(discord.ui.Button):
@@ -110,7 +110,7 @@ class StopTrackButton(discord.ui.Button):
 
         await self.view.prepare()
         kwargs = await self.view.get_page(self.view.current_page)
-        await (await interaction.original_message()).edit(view=self.view, **kwargs)
+        await context.message.edit(view=self.view, **kwargs)
 
 
 class DisconnectAllButton(discord.ui.Button):
@@ -168,4 +168,4 @@ class DisconnectAllButton(discord.ui.Button):
 
         await self.view.prepare()
         kwargs = await self.view.get_page(self.view.current_page)
-        await (await interaction.original_message()).edit(view=self.view, **kwargs)
+        await context.message.edit(view=self.view, **kwargs)
